@@ -1,13 +1,13 @@
 use std::borrow::Cow;
 
-use poem::web::Field as PoemField;
+use poem::{http::HeaderValue, web::Field as PoemField};
 use serde_json::Value;
 
 use crate::{
     registry::{MetaSchemaRef, Registry},
     types::{
         ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
-        ToJSON, Type,
+        ToHeader, ToJSON, Type,
     },
 };
 
@@ -16,6 +16,8 @@ impl<T: Type> Type for Option<T> {
 
     type RawValueType = T::RawValueType;
 
+    type RawElementValueType = T::RawElementValueType;
+
     fn name() -> Cow<'static, str> {
         T::name()
     }
@@ -34,6 +36,15 @@ impl<T: Type> Type for Option<T> {
             None => None,
         }
     }
+
+    fn raw_element_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a> {
+        match self {
+            Some(value) => value.raw_element_iter(),
+            None => Box::new(std::iter::empty()),
+        }
+    }
 }
 
 impl<T: ParseFromJSON> ParseFromJSON for Option<T> {
@@ -79,3 +90,12 @@ impl<T: ToJSON> ToJSON for Option<T> {
         }
     }
 }
+
+impl<T: ToHeader> ToHeader for Option<T> {
+    fn to_header(&self) -> Option<HeaderValue> {
+        match self {
+            Some(value) => value.to_header(),
+            None => None,
+        }
+    }
+}
