@@ -9,12 +9,16 @@ use crate::{
 };
 
 impl<T: Type> Type for Vec<T> {
+    const IS_REQUIRED: bool = true;
+
+    type RawValueType = Self;
+
+    type RawElementValueType = T::RawValueType;
+
     fn name() -> Cow<'static, str> {
         format!("[{}]", T::name()).into()
     }
 
-    impl_raw_value_type!();
-
     fn schema_ref() -> MetaSchemaRef {
         MetaSchemaRef::Inline(Box::new(MetaSchema {
             items: Some(Box::new(T::schema_ref())),
@@ -25,6 +29,16 @@ impl<T: Type> Type for Vec<T> {
     fn register(registry: &mut Registry) {
         T::register(registry);
     }
+
+    fn as_raw_value(&self) -> Option<&Self::RawValueType> {
+        Some(self)
+    }
+
+    fn raw_element_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a> {
+        Box::new(self.iter().map(|item| item.as_raw_value()).flatten())
+    }
 }
 
 impl<T: ParseFromJSON> ParseFromJSON for Vec<T> {
